@@ -2,5 +2,6 @@ from .jsontable import JsonTable
 from .jsonquerier import JsonQuerier
 from .model import JsonModel, TABLE_REGISTRY
 from .foreignkey import ForeignKey
+from .datatypes.hashed import Hashed
 
-__all__ = ["JsonTable", "JsonQuerier", "JsonModel", "ForeignKey", "TABLE_REGISTRY"]
\ No newline at end of file
+__all__ = ["JsonTable", "JsonQuerier", "JsonModel", "ForeignKey", "TABLE_REGISTRY", "Hashed"]
\ No newline at end of file
